Skip to contents

Small data set of six types of goods.

Usage

data("trade_goods", package = "MultiFactor")

Format

trade_goods: A small tidy data set used in the vignette, describing six items from six categories (36 rows); The 4 columns contain their name, associated emoji, unicode runes (sans U+ prefix) and group as well as their associated emoji and unicode ID, sans U+ prefix.

trade_goods: Curated using the emo package.