Skip to contents

weave() is an S7 generic that finds a path through a relational object.

Usage

weave(x, .path, ...)

Arguments

x

input object

.path

either a formula or a character vector of length 2 with the names of the desired combination of feature types.

...

additional arguments

Value

a LinkMap or matrix.

Examples

# Available methods:
weave
#> <S7_generic> weave(x, .path, ...) with 1 methods:
#> 1: method(weave, MultiFactor::MultiFactor)